IKPdb is written and maintained by Cyril MORISSE and various contributors:

Development Lead
________________

- Cyril MORISSE <cmorisse@boxes3.net>


Patches, Suggestions and Reviews
________________________________

- Assem BAYAHI <bayahiassem@gmail.com>
- Jérome MARIEN <marien.jer@gmail.com>
